@@ -1,16 +1,12 @@
-from viset.mnist import MNIST
+from viset.library.mnist import MNIST
 from viset.dataset import Viset
 from viset.show import imshow
 from time import sleep
 
 def main():
-    try:
-        db = Viset('mnist.h5', datastep=100, async=False, verbose=True)
-    except:
-        dbfile = MNIST().export()
-        db = Viset(dbfile, datastep=100, async=False, verbose=True)
-
-    for (im,annotation) in db[0]:
+    dbfile = MNIST(verbose=True).export()
+    db = Viset(dbfile, verbose=True)
+    for (im,annotation) in db.annotation.categorization(step=100):
         print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
         imshow(im, title=annotation['category'])
         
