@@ -74,15 +74,15 @@ class Viset(object):
 
     def summary(self):
         print 'Database URL: ' + self.url
-        print 'Database local file: ' + self._cache.get(self.url)
-        print 'Dataset name: ' + str(self.name())            
-        print 'Database verbosity: ' + str(self._verbose)        
-        print 'Cache directory: ' + self._cache._cacheroot
+        print 'Database name: ' + str(self.name())            
         print 'Database views: ' + str(self.views())
         print 'Number of images: ' + str(len(self.image))
         print 'Number of annotation views: ' + str(len(self.annotation))
-        print 'HDF5 database file structure: ' 
+        print 'Database verbosity: ' + str(self._verbose)        
+        print 'HDF5 file structure: ' 
         print '  ' + "\n  ".join(str(self._obj).split("\n"))
+        print 'Cache directory: ' + self._cache._cacheroot
+        print 'Database local file: ' + self._cache.get(self.url)
         return str()
         
     def open(self, dburl):
